package fr.aminelouveaau.cartes.service;

import fr.aminelouveaau.cartes.model.Number;
import fr.aminelouveaau.cartes.model.Shape;
import javafx.util.Pair;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import java.util.*;

@Service
public class GameService {
    @Value("${cards.hand.number}")
    private Integer cardHandNumber;

    private List<Shape> shapeOrder;
    private List<Number> numberOrder;

    private List<Pair<Shape, Number>> deck = new ArrayList<>();

    @PostConstruct
    public void init() {
        generateOrders();
        createDeck();
    }

    public List<Shape> getShapeOrder() {
        return shapeOrder;
    }

    public List<Number> getNumberOrder() {
        return numberOrder;
    }

    public List<Pair<Shape, Number>> getDeck() {
        return deck;
    }

    private void createDeck() {
        Arrays.stream(Shape.values()).forEach(shape -> {
            Arrays.stream(Number.values()).forEach(number -> {
                deck.add(new Pair<>(shape, number));
            });
        });
        Collections.shuffle(deck);
    }

    private void generateOrders() {
        List<Shape> shapeOrder = Arrays.asList(Shape.values());
        Collections.shuffle(shapeOrder);
        List<Number> numberOrder = Arrays.asList(Number.values());
        Collections.shuffle(numberOrder);
    }

}
